@@ -515,6 +515,20 @@ class SimpleCodebuildProject(
 
         return typing.cast("SimpleCodebuildProject", jsii.invoke(self, "assemble", [default_props]))
 
+    @jsii.member(jsii_name="buildImage")
+    def build_image(
+        self,
+        build_image: aws_cdk.aws_codebuild.IBuildImage,
+    ) -> "SimpleCodebuildProject":
+        '''The build image to use.
+
+        :param build_image: -
+
+        :see: https://docs.aws.amazon.com/cdk/api/v1/docs/
+        :aws-cdk_aws-codebuild: .IBuildImage.html
+        '''
+        return typing.cast("SimpleCodebuildProject", jsii.invoke(self, "buildImage", [build_image]))
+
     @jsii.member(jsii_name="buildSpecPath")
     def build_spec_path(
         self,
@@ -539,6 +553,19 @@ class SimpleCodebuildProject(
         '''
         return typing.cast("SimpleCodebuildProject", jsii.invoke(self, "computeType", [compute_type]))
 
+    @jsii.member(jsii_name="ecrBuildImage")
+    def ecr_build_image(
+        self,
+        ecr_repo_name: builtins.str,
+        image_tag: builtins.str,
+    ) -> "SimpleCodebuildProject":
+        '''The build image to use.
+
+        :param ecr_repo_name: - the ecr repository name.
+        :param image_tag: - the image tag.
+        '''
+        return typing.cast("SimpleCodebuildProject", jsii.invoke(self, "ecrBuildImage", [ecr_repo_name, image_tag]))
+
     @jsii.member(jsii_name="gitBaseBranch")
     def git_base_branch(self, branch: builtins.str) -> "SimpleCodebuildProject":
         '''The main branch of the github project.
@@ -555,6 +582,16 @@ class SimpleCodebuildProject(
         '''
         return typing.cast("SimpleCodebuildProject", jsii.invoke(self, "gitRepoUrl", [git_repo_url]))
 
+    @jsii.member(jsii_name="inVpc")
+    def in_vpc(self, vpc_id: builtins.str) -> "SimpleCodebuildProject":
+        '''The vpc network interfaces to add to the codebuild.
+
+        :param vpc_id: -
+
+        :see: https://docs.aws.amazon.com/cdk/api/v1/docs/aws-codebuild-readme.html#definition-of-vpc-configuration-in-codebuild-project
+        '''
+        return typing.cast("SimpleCodebuildProject", jsii.invoke(self, "inVpc", [vpc_id]))
+
     @jsii.member(jsii_name="overrideProjectProps")
     def override_project_props(
         self,
@@ -763,15 +800,17 @@ class Utils(metaclass=jsii.JSIIMeta, jsii_type="ez-constructs.Utils"):
         cls,
         stack: aws_cdk.Stack,
         persist: typing.Optional[builtins.bool] = None,
+        path: typing.Optional[builtins.str] = None,
     ) -> None:
         '''A utility function that will print the content of a CDK stack.
 
         :param stack: - a valid stack.
         :param persist: -
+        :param path: -
 
         :warning: This function is only used for debugging purpose.
         '''
-        return typing.cast(None, jsii.sinvoke(cls, "prettyPrintStack", [stack, persist]))
+        return typing.cast(None, jsii.sinvoke(cls, "prettyPrintStack", [stack, persist, path]))
 
     @jsii.member(jsii_name="startsWith") # type: ignore[misc]
     @builtins.classmethod
